# Installation

It is recommended not to install the OU Container Builder globally. Instead use an environment manager such as
[Hatch](https://hatch.pypa.io/) or [Poetry](https://python-poetry.org/) and then add the OU Container Builder
as a dependency. To install the appropriate version for this documentation use the following constraint:

```
ou_container_builder>=3,<4
```
